package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalUserPost;

/**
 * 用户与岗位关联Service接口
 * 
 * @author fs
 * @date 2024-02-27
 */
public interface IHospitalUserPostService 
{
    /**
     * 查询用户与岗位关联
     * 
     * @param userId 用户与岗位关联主键
     * @return 用户与岗位关联
     */
    public HospitalUserPost selectHospitalUserPostByUserId(Long userId);

    /**
     * 查询用户与岗位关联列表
     * 
     * @param hospitalUserPost 用户与岗位关联
     * @return 用户与岗位关联集合
     */
    public List<HospitalUserPost> selectHospitalUserPostList(HospitalUserPost hospitalUserPost);

    /**
     * 新增用户与岗位关联
     * 
     * @param hospitalUserPost 用户与岗位关联
     * @return 结果
     */
    public int insertHospitalUserPost(HospitalUserPost hospitalUserPost);

    /**
     * 修改用户与岗位关联
     * 
     * @param hospitalUserPost 用户与岗位关联
     * @return 结果
     */
    public int updateHospitalUserPost(HospitalUserPost hospitalUserPost);

    /**
     * 批量删除用户与岗位关联
     * 
     * @param userIds 需要删除的用户与岗位关联主键集合
     * @return 结果
     */
    public int deleteHospitalUserPostByUserIds(Long[] userIds);

    /**
     * 删除用户与岗位关联信息
     * 
     * @param userId 用户与岗位关联主键
     * @return 结果
     */
    public int deleteHospitalUserPostByUserId(Long userId);
}
